package org.acme.mongodb.panache;

import io.quarkus.test.junit.QuarkusIntegrationTest;

@QuarkusIntegrationTest
public class PersonResourceIT extends PersonResourceTest {

    // Run the same tests

}
